# Django settings for deploy_tracker project.

import os
import pwd
from datetime import timedelta

import dj_database_url
import djcelery
from getenv import env

# Needed to have celery work from management commands
djcelery.setup_loader()


# base directories

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
_LOGS_DIR = os.path.abspath(
    os.path.join(BASE_DIR, os.pardir, os.pardir, 'logs'))
LOGS_DIR = os.path.abspath(os.getenv('DPA_LOGS_DIR', _LOGS_DIR))
HOST_DIR = os.path.abspath(
    os.getenv('DPA_LP_CACHE_HOST_DIR', os.path.abspath(
        os.path.join(BASE_DIR, os.path.pardir, os.path.pardir))))
OOPS_DIR = os.path.join(LOGS_DIR, 'www-oops')
SRC_DIR = os.path.join(BASE_DIR, 'revtracker')

# django settings

ADMIN_MEDIA_PREFIX = '/static/admin/'
ALLOWED_HOSTS = env('ALLOWED_HOSTS', '[]')
AUTHENTICATION_BACKENDS = (
    'django_openid_auth.auth.OpenIDBackend',
    'django.contrib.auth.backends.ModelBackend',
)
CSRF_COOKIE_DOMAIN = None
CSRF_COOKIE_HTTPONLY = False
CSRF_COOKIE_NAME = 'csrftoken'
CSRF_COOKIE_PATH = '/'
CSRF_COOKIE_SECURE = False
CSRF_FAILURE_VIEW = 'django.views.csrf.csrf_failure'
DATABASES = {
        'default': dj_database_url.config(
            default='postgres://postgres@localhost/revtracker')
}
DEBUG = env('DEBUG', '').lower() == 'true'
INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.comments',
    'django.contrib.admin',
    'devserver',
    'django_openid_auth',
    'djcelery',
    'revtracker',
    'waffle',
    'ordered_model',
    'checklist',
    'pgtools',
    #'debug_toolbar',
)
INTERNAL_IPS = ('127.0.0.1',)
LANGUAGE_CODE = 'en-us'
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'filters': ['require_debug_false'],
        },
        'file': {
            'level': 'INFO',
            'class': 'logging.handlers.WatchedFileHandler',
            'formatter': 'verbose',
            'filename': os.path.join(LOGS_DIR, 'deployable.log'),
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
        'django': {
            'handlers': ['file'],
            'level': 'WARNING',
        },
    },
    'formatters': {
        'verbose': {
            'format': '%(levelname)s %(asctime)s %(module)s %(process)d %(thread)d %(message)s',
        },
    },
    'filters': {
         'require_debug_false': {
              '()': 'django.utils.log.RequireDebugFalse',
         },
    }
}
LOGIN_URL = '/openid/login'
LOGIN_REDIRECT_URL = '/'
MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'waffle.middleware.WaffleMiddleware',
    #'debug_toolbar.middleware.DebugToolbarMiddleware',
)
ROOT_URLCONF = 'django_project.urls'
SECRET_KEY = env('SECRET_KEY', '')
SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
STATIC_ROOT = 'static'
STATIC_URL = '/static/'
STATICFILES_DIRS = (
    os.path.join(BASE_DIR, 'build/revtracker/js'),
)
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)
TEMPLATE_CONTEXT_PROCESSORS = (
    "django.contrib.auth.context_processors.auth",
    "django.core.context_processors.csrf",
    "django.core.context_processors.static",
    "django.core.context_processors.request",
)
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    'django.template.loaders.eggs.Loader',
)
TEST_RUNNER = 'django.test.runner.DiscoverRunner'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True

# debug-toolbar settings

DEBUG_TOOLBAR_CONFIG = {
    'INTERCEPT_REDIRECTS': False,
}

# celery settings

CELERY_BROKER_URL = os.getenv('CELERY_BROKER_URL', 'amqp://')
CELERY_ACCEPT_CONTENT = ['json']
CELERY_TASK_SERIALIZER = 'json'
CELERY_RESULT_SERIALIZER = 'json'
CELERYBEAT_SCHEDULE = {
    "update_all_projects": {
        "task": "revtracker.tasks.update_all_projects",
            "schedule": timedelta(minutes=5),
        },
    }
# Only reserve one task per worker, so that workers don't sit idle
# during long running tasks.
CELERYD_PREFETCH_MULTIPLIER = 1
CELERYBEAT_SCHEDULE_FILENAME = 'tmp/celerybeat-schedule'

# django-openid-auth settings

OPENID_CREATE_USERS = True
OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO = True
OPENID_UPDATE_DETAILS_FROM_SREG = True
OPENID_SREG_REQUIRED_FIELDS = ['nickname']
OPENID_SSO_SERVER_URL = 'https://login.ubuntu.com/'

# revtracker settings

BRANCH_CACHE_DIR = "branches"
COMBO_URL = env('COMBO_URL', 'http://127.0.0.1:8001/')
CONVOY_ROOT = os.path.join(STATIC_ROOT, 'combo')
GIT_SSH_DEFAULT_USERNAME = pwd.getpwuid(os.getuid()).pw_name
GIT_SSH_DEFAULT_PORT = None
GIT_SSH_PRIVATE_KEY = os.path.expanduser('~/.ssh/id_rsa')
GIT_SSH_PUBLIC_KEY = os.path.expanduser('~/.ssh/id_rsa.pub')
LP_INSTANCE = 'production'
MULTILANG_OP_ENDPOINTS = False
OOPSES = {
    'publishers': [{
        'inherit_id': False,
        'error_dir': OOPS_DIR,
        'type': 'datedir',
        'new_only': False,
    }],
    'template': {'reporter': 'DEFAULT'},
}
SOFT_TIMEOUT_MILLISECONDS = 10000
USE_HTTPS = env('USE_HTTPS', 'true').lower() == 'true'
WAFFLE_OVERRIDE = True
